/* GCC */

#include <iomanip>
#include <fstream>
#include <cmath>
#include <vector>
#include <map>
#include <iostream>
#include <algorithm>

std::vector<uint_fast32_t> primes;
std::vector<uint_fast32_t> factors;
std::vector<uint_fast64_t> answers;

uint_fast64_t m = 0;
uint_fast32_t n = 0;

std::map<uint_fast32_t, uint_fast32_t> primeFactorsCount;

inline void countPrimes()
{
    for(uint_fast32_t i = 0; i < factors.size(); i++)
    {
        primeFactorsCount[i]++;
    }
}

inline uint_fast32_t product()
{
    uint_fast32_t product = 1;
    for(int i = 0; i < primeFactorsCount.size(); i++)
        product *= (primeFactorsCount.at(i) + 1);
    return product;
}

inline uint_fast32_t product(uint32_t * indexes)
{
    uint_fast32_t product = 1;
    for(int i = 0; i < primeFactorsCount.size(); i++)
        product *= (primeFactorsCount.at(i) + indexes[i] + 1);
    return product;
}

void solveEverything(uint32_t * indexes)
{
    if(indexes == 0)
    {
        indexes = new uint_fast32_t[m]();
        for(uint_fast32_t i = 0; i < factors.size(); i++)
            indexes[i] = 0;
    }

    uint_fast32_t tmp = product(indexes);

    if(tmp == n)
    {
        uint_fast64_t answer = 1;
        for(uint_fast32_t i = 0; i < factors.size(); i++)
        {
            answer *= std::ceil(pow(factors[i], primeFactorsCount[i] + indexes[i]));
        }
        answers.push_back(answer);
        return;
    }

    if(tmp > n)
    {
        delete[] indexes;
        return;
    }

    for(int i = 0; i < factors.size(); i++)
    {
        uint_fast32_t * tmpIndexes = new uint_fast32_t[n]();
        for(int k = 0; k < factors.size(); k++ )
            tmpIndexes[k] = indexes[k];
        tmpIndexes[i]++;

        solveEverything(tmpIndexes);
    }
}

int main()
{
    std::ifstream in("divisors.in");
    std::ofstream out("divisors.out");

    answers.empty();
    primeFactorsCount.empty();
    factors.empty();
    primes.empty();

    in >> m >> n;

    //Find primes.

    for(uint_fast32_t i = 2; i <= sqrt(m) + 2; i++)
    {
        bool prime = true;
        for(int k = 0; k < primes.size(); k++)
        {
            if(i % primes[k] == 0)
            {
                prime = false;
                break;
            }
        }

        if(prime)
            primes.push_back(i);
    }

    //Factor out given number.

    uint_fast32_t lowestPrime = 0;
    uint_fast32_t tempM = m;


    uint_fast32_t factorsCount = 0;

    while(tempM >= 1)
    {
        if(tempM % primes[lowestPrime] == 0)
        {
            factors.push_back(primes[lowestPrime]);
            tempM /= primes[lowestPrime];
            factorsCount++;
        }
        else
        {
            lowestPrime++;
            if(lowestPrime >= primes.size())
                break;
        }
    }

    countPrimes();

    primes.empty();

    solveEverything(0);

    out << std::fixed;

    if(answers.size() == 0)
    {
        out << 0;
        return 0;
    }

    uint_fast64_t fin = answers[0];
    out << answers[0];

    for(uint_fast32_t i = 1; i < answers.size(); i++)
    {
        if(answers[i] !=  fin)
        {
            out << " " <<  answers[i];
            fin = answers[i];
        }
    }

    return 0;
}
